==> docx4j-openxml-objects-8.2.8-sources.jar: org/docx4j/vml/officedrawing/STExtrusionPlane.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.vml.officedrawing;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ExtrusionPlane.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ExtrusionPlane">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="XY"/>
 *     &lt;enumeration value="ZX"/>
 *     &lt;enumeration value="YZ"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_ExtrusionPlane")
@XmlEnum
public enum STExtrusionPlane {


    /**
     * XY Plane
     * 
     */
    XY,

    /**
     * ZX Plane
     * 
     */
    ZX,

    /**
     * YZ Plane
     * 
     */
    YZ;

    public String value() {
        return name();
    }

    public static STExtrusionPlane fromValue(String v) {
        return valueOf(v);
    }

}

==> docx4j-openxml-objects-11.4.11-sources.jar: org/docx4j/vml/officedrawing/STExtrusionPlane.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.vml.officedrawing;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_ExtrusionPlane.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_ExtrusionPlane">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="XY"/>
 *     &lt;enumeration value="ZX"/>
 *     &lt;enumeration value="YZ"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_ExtrusionPlane")
@XmlEnum
public enum STExtrusionPlane {


    /**
     * XY Plane
     * 
     */
    XY,

    /**
     * ZX Plane
     * 
     */
    ZX,

    /**
     * YZ Plane
     * 
     */
    YZ;

    public String value() {
        return name();
    }

    public static STExtrusionPlane fromValue(String v) {
        return valueOf(v);
    }

}
